@@ -135,14 +135,14 @@ class AccountInvoiceTestCase(ModuleTestCase):
                                     }])]
                     }])
         terms = remainder_term.compute(Decimal('0.0'), cu1,
-            date=datetime.date(2016, 05, 17))
+            date=datetime.date(2016, 5, 17))
         self.assertEqual(terms, [
-                (datetime.date(2016, 05, 17), Decimal('0.0')),
+                (datetime.date(2016, 5, 17), Decimal('0.0')),
                 ])
         terms = percent_term.compute(Decimal('0.0'), cu1,
-            date=datetime.date(2016, 05, 17))
+            date=datetime.date(2016, 5, 17))
         self.assertEqual(terms, [
-                (datetime.date(2016, 05, 17), Decimal('0.0')),
+                (datetime.date(2016, 5, 17), Decimal('0.0')),
                 ])
 
     @with_transaction()
@@ -225,4 +225,14 @@ def suite():
             tearDown=doctest_teardown, encoding='utf-8',
             checker=doctest_checker,
             optionflags=doctest.REPORT_ONLY_FIRST_FAILURE))
+    suite.addTests(doctest.DocFileSuite(
+            'scenario_invoice_alternate_currency_lower_rate.rst',
+            tearDown=doctest_teardown, encoding='utf-8',
+            checker=doctest_checker,
+            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE))
+    suite.addTests(doctest.DocFileSuite(
+            'scenario_renew_fiscalyear.rst',
+            tearDown=doctest_teardown, encoding='utf-8',
+            checker=doctest_checker,
+            optionflags=doctest.REPORT_ONLY_FIRST_FAILURE))
     return suite
